sprockets.handlers.heartbeat
============================
A callback-based heartbeat handler

|Version| |Downloads| |Status| |Coverage| |License|

Installation
------------
``sprockets.handlers.heartbeat`` is available on the
`Python Package Index <https://pypi.python.org/pypi/sprockets.handlers.heartbeat>`_
and can be installed via ``pip`` or ``easy_install``:

.. code:: bash

  pip install sprockets.handlers.heartbeat

Requirements
------------
- `tornado <https://github.com/tornadoweb/tornado>`_

API Documentation
-----------------
.. toctree::
   :maxdepth: 2

   api
   examples

Version History
---------------
See :doc:`history`

Issues
------
Please report any issues to the Github project at `https://github.com/sprockets/sprockets.handlers.heartbeat/issues <https://github.com/sprockets/sprockets.handlers.heartbeat/issues>`_

Source
------
``sprockets.handlers.heartbeat`` source is available on Github at `https://github.com/sprockets/sprockets.handlers.heartbeat <https://github.com/sprockets/sprockets.handlers.heartbeat>`_

License
-------
``sprockets.handlers.heartbeat`` is released under the `3-Clause BSD license <https://github.com/sprockets/sprockets.handlers.heartbeat/blob/master/LICENSE>`_.

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |Version| image:: https://badge.fury.io/py/sprockets.handlers.heartbeat.svg?
   :target: http://badge.fury.io/py/sprockets.handlers.heartbeat

.. |Status| image:: https://travis-ci.org/sprockets/sprockets.handlers.heartbeat.svg?branch=master
   :target: https://travis-ci.org/sprockets/sprockets.handlers.heartbeat

.. |Coverage| image:: https://img.shields.io/coveralls/sprockets/sprockets.handlers.heartbeat.svg?
   :target: https://coveralls.io/r/sprockets/sprockets.handlers.heartbeat

.. |Downloads| image:: https://pypip.in/d/sprockets.handlers.heartbeat/badge.svg?
   :target: https://pypi.python.org/pypi/sprockets.handlers.heartbeat

.. |License| image:: https://pypip.in/license/sprockets.handlers.heartbeat/badge.svg?
   :target: https://sprocketshandlersheartbeat.readthedocs.org